#updated 20230302
#oagImportGame.ps1

function Add-NewEmulatedGame(
	[parameter(mandatory)]$playniteEmulator,
	[parameter(mandatory)][string]$sGameName,
	[parameter(mandatory)][string]$sGameDirInstall,
	[string]$sGameDirImage = '',
	[string]$sRegion = '',
	[string]$sVersion = '',
	$Platform,
	[parameter()]$OptionalAdditionalArguments,
	[string]$OptionalProfileName = ''
) {

	[bool]$bResult = $false
	[string]$fullnameTempImage = ''

	$game = New-Object "Playnite.SDK.Models.Game" $sGameName
	$game.IsInstalled = $true
	$game.InstallDirectory = $sGameDirInstall


	# set region
	if ($sRegion) {
		New-Variable -Name "Object_$($sRegion)" -Value $($PlayniteApi.Database.Regions.Add($sRegion)) -Force
		New-Variable -Name "Guid_$($sRegion)" -Value $($(Get-Variable -Name "Object_$($sRegion)").Value).Id -Force
		$game.RegionId = [guid]$(Get-Variable -Name "Guid_$($sRegion)" -ValueOnly)
	}

	if ($Platform) {
		$game.PlatformId = $Platform.Id
	}
	if ($sGameDirImage) {
		$game.GameImagePath = $sGameDirImage
	}
	if ($sVersion) {
		$game.Version = $sVersion
	}

	$playTask = New-Object "Playnite.SDK.Models.GameAction"
	$playTask.Type = "Emulator"
	if ($OptionalAdditionalArguments) {
		$playTask.AdditionalArguments = $OptionalAdditionalArguments
	}
	$playTask.EmulatorId = $playniteEmulator.Id


	if ($OptionalProfileName) {
		$playTask.EmulatorProfileId = ($playniteEmulator.Profiles | Where-Object { ($_.name -eq $OptionalProfileName) } | Select-Object -First 1).id
	} else {
		$playTask.EmulatorProfileId = $playniteEmulator.Profiles[0].Id
	}

	$game.PlayAction = $playTask

	$null = $PlayniteApi.Database.Games.Add($game)

	$bResult = $true
	return $bResult
}

function Confirm-OkayToAddGameNotImported(
	[parameter(mandatory)][string]$sGameName,
	[parameter(mandatory)][string]$sGameDirInstall,
	[string]$sGameDirImage = ''
) {
	[bool]$bResult = $true
	[string]$sExistingPath = ''
	[bool]$bAllowDuplicatesForTesting = ([System.IO.File]::Exists("$CurrentExtensionDataPath\IMPORT_DUPLICATES_ENABLED"))
	[string]$sMsg = ''

	if ($sGameDirImage) {
		if ($PlayniteApi.Database.Games | Where { $_.GameImagePath -eq $sGameDirImage }) {
			$sExistingPath = $sGameDirImage
		} else {
			$matchedGames = $PlayniteApi.Database.Games | Where { ($_.GameId) }

			if ((($matchedGames | Where { $_.GameId -like "*$sGameDirImage*" }).count) -gt 0) {
				$sExistingPath = 'EmuLibrary'
			}
		}
	} else {
		if ($PlayniteApi.Database.Games | Where { $_.InstallDirectory -eq $sGameDirInstall }) {
			$sExistingPath = $sGameDirInstall
		} else {
<# 			if ($PlayniteApi.Database.Games | Where { $sGameDirInstall -match [RegEx]::Escape($_.InstallDirectory) }) {
				$sExistingPath = $sGameDirInstall
			} #>
		}
	}

	if ($sExistingPath) {
		if ($bAllowDuplicatesForTesting -eq $false) {
			$sMsg = "skip import of '$sGameName' - game is already in Playnite ($sExistingPath)"
			$__logger.Info($sMsg)
			$bResult = $false
		}
	}

	return $bResult
}

function Confirm-OkayToAddGameExists(
	[string]$sGameName,
	[string]$sGameDirInstall,
	[string]$sGameDirImage = ''
) {
	[bool]$bResult = $false
	[string]$sMsg = ''

	if ($sGameDirImage) {
		if ([System.IO.File]::Exists($sGameDirImage)) {
			$bResult = $true
		}
	} else {
		# e.g. ScummVM
		if ($sGameDirInstall) {
			if ($sGameDirInstall.EndsWith('\')) {
				if ([System.IO.Directory]::Exists($sGameDirInstall)) {
					$bResult = $true
				}
			}
		}
	}

	if ($bResult -eq $false) {
		$sMsg = "skip import of '$sGameName' - path is invalid '$sGameDirInstall' '$sGameDirImage'"
		$__logger.Warn($sMsg)
	}

	return $bResult
}